;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tidal" "20250711.1955"
  "Interact with TidalCycles for live coding patterns."
  '((haskell-mode "16")
    (emacs        "25.1"))
  :url "https://codeberg.org/uzu/tidal"
  :commit "660ac746ec5c89da7ead100c0c46bf67e4037f41"
  :revdesc "660ac746ec5c"
  :keywords '("tools")
  :authors '((nil . "alex@slab.org"))
  :maintainers '((nil . "alex@slab.org")))
